<?php return array(
    'root' => array(
        'name' => 'dokuwiki/dokuwiki',
        'pretty_version' => 'dev-master',
        'version' => 'dev-master',
        'reference' => '87f6c7185502767dd23d1039195eed23f0048dd1',
        'type' => 'project',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => true,
    ),
    'versions' => array(
        'aziraphale/email-address-validator' => array(
            'pretty_version' => '2.0.1',
            'version' => '2.0.1.0',
            'reference' => 'fa25bc22c1c0b6491657c91473fae3e40719a650',
            'type' => 'library',
            'install_path' => __DIR__ . '/../aziraphale/email-address-validator',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dokuwiki/dokuwiki' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'reference' => '87f6c7185502767dd23d1039195eed23f0048dd1',
            'type' => 'project',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'geshi/geshi' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'reference' => '7884d22244c6d2de5ac7ffd919ce4add02b36e66',
            'type' => 'library',
            'install_path' => __DIR__ . '/../geshi/geshi',
            'aliases' => array(
                0 => '9999999-dev',
                1 => '1.0.x-dev',
            ),
            'dev_requirement' => false,
        ),
        'kissifrot/php-ixr' => array(
            'pretty_version' => '1.8.4',
            'version' => '1.8.4.0',
            'reference' => '45f6e4d46c1f9bb49e41a1787b6bdbcc9ab788e4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../kissifrot/php-ixr',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'openpsa/universalfeedcreator' => array(
            'pretty_version' => 'v1.8.6',
            'version' => '1.8.6.0',
            'reference' => '3abf36ef9d3a3b31a3c330caea7d5176f0396301',
            'type' => 'library',
            'install_path' => __DIR__ . '/../openpsa/universalfeedcreator',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'paragonie/constant_time_encoding' => array(
            'pretty_version' => 'v2.6.3',
            'version' => '2.6.3.0',
            'reference' => '58c3f47f650c94ec05a151692652a868995d2938',
            'type' => 'library',
            'install_path' => __DIR__ . '/../paragonie/constant_time_encoding',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'paragonie/random_compat' => array(
            'pretty_version' => 'v9.99.100',
            'version' => '9.99.100.0',
            'reference' => '996434e5492cb4c3edcb9168db6fbb1359ef965a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../paragonie/random_compat',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phpseclib/phpseclib' => array(
            'pretty_version' => '3.0.35',
            'version' => '3.0.35.0',
            'reference' => '4b1827beabce71953ca479485c0ae9c51287f2fe',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpseclib/phpseclib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'simplepie/simplepie' => array(
            'pretty_version' => '1.8.0',
            'version' => '1.8.0.0',
            'reference' => '65b095d87bc00898d8fa7737bdbcda93a3fbcc55',
            'type' => 'library',
            'install_path' => __DIR__ . '/../simplepie/simplepie',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'splitbrain/lesserphp' => array(
            'pretty_version' => 'v0.10.0',
            'version' => '0.10.0.0',
            'reference' => '2e5d20c4ce9186a34554a137a4a1784fc5c29505',
            'type' => 'library',
            'install_path' => __DIR__ . '/../splitbrain/lesserphp',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'splitbrain/php-archive' => array(
            'pretty_version' => '1.3.1',
            'version' => '1.3.1.0',
            'reference' => 'd274e5190ba309777926348900cf9578d9e533c9',
            'type' => 'library',
            'install_path' => __DIR__ . '/../splitbrain/php-archive',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'splitbrain/php-cli' => array(
            'pretty_version' => '1.3.1',
            'version' => '1.3.1.0',
            'reference' => '844609ef16b8486691b7fd892d54478918f27fe8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../splitbrain/php-cli',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'splitbrain/php-jsstrip' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => '21254b19b381a25d6f3dd89dbd5c8191373a4d69',
            'type' => 'library',
            'install_path' => __DIR__ . '/../splitbrain/php-jsstrip',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'splitbrain/slika' => array(
            'pretty_version' => '1.0.6',
            'version' => '1.0.6.0',
            'reference' => '274511fc654fa29cb7cfc039bed97a5ea786f1a0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../splitbrain/slika',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
