<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author cadetill <cadetill@gmail.com>
 */
$lang['menu']                  = 'Ver registros';
$lang['date']                  = 'Fecha';
